# nanako-utils

A collection of utilities. Feel free to use it if you find it useful.

**Warning**: This project is only for my own purposes. The API is subject to change at any time.

## Installation

```bash
pip install nanako-utils
```

## Usage

```python
import nnkutils
```
